@@ -57,7 +57,15 @@ class newbytes(_builtin_bytes):
         elif isinstance(args[0], unicode):
             if 'encoding' not in kwargs:
                 raise TypeError('unicode string argument without an encoding')
-            value = args[0].encode(**kwargs)
+            ###
+            # Was:   value = args[0].encode(**kwargs)
+            # Python 2.6 string encode() method doesn't take kwargs:
+            # Use this instead:
+            newargs = [kwargs['encoding']]
+            if 'errors' in kwargs:
+                newargs.append(kwargs['errors'])
+            value = args[0].encode(*newargs)
+            ### 
         elif isinstance(args[0], Iterable):
             if len(args[0]) == 0:
                 # What is this?
@@ -79,7 +87,7 @@ class newbytes(_builtin_bytes):
         return 'b' + super(newbytes, self).__repr__()
 
     def __str__(self):
-        return 'b' + "'{}'".format(super(newbytes, self).__str__())
+        return 'b' + "'{0}'".format(super(newbytes, self).__str__())
 
     def __getitem__(self, y):
         value = super(newbytes, self).__getitem__(y)
@@ -88,6 +96,9 @@ class newbytes(_builtin_bytes):
         else:
             return newbytes(value)
 
+    def __getslice__(self, *args):
+        return self.__getitem__(slice(*args))
+
     def __contains__(self, key):
         if isinstance(key, int):
             newbyteskey = newbytes([key])
@@ -114,7 +125,7 @@ class newbytes(_builtin_bytes):
         return newbytes(super(newbytes, self).__rmul__(other))
 
     def join(self, iterable_of_bytes):
-        errmsg = 'sequence item {}: expected bytes, {} found'
+        errmsg = 'sequence item {0}: expected bytes, {1} found'
         if isbytes(iterable_of_bytes) or istext(iterable_of_bytes):
             raise TypeError(errmsg.format(0, type(iterable_of_bytes)))
         for i, item in enumerate(iterable_of_bytes):
@@ -227,7 +238,7 @@ class newbytes(_builtin_bytes):
         else:
             return True
 
-    unorderable_err = 'unorderable types: bytes() and {}'
+    unorderable_err = 'unorderable types: bytes() and {0}'
 
     def __lt__(self, other):
         if not isbytes(other):
